@@ -7,6 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_devops_guru import (
         Client,
+        DescribeOrganizationResourceCollectionHealthPaginator,
         DescribeResourceCollectionHealthPaginator,
         DevOpsGuruClient,
         GetCostEstimationPaginator,
@@ -15,8 +16,10 @@ Usage::
         ListEventsPaginator,
         ListInsightsPaginator,
         ListNotificationChannelsPaginator,
+        ListOrganizationInsightsPaginator,
         ListRecommendationsPaginator,
         SearchInsightsPaginator,
+        SearchOrganizationInsightsPaginator,
     )
 
     session = boto3.Session()
@@ -24,6 +27,7 @@ Usage::
     client: DevOpsGuruClient = boto3.client("devops-guru")
     session_client: DevOpsGuruClient = session.client("devops-guru")
 
+    describe_organization_resource_collection_health_paginator: DescribeOrganizationResourceCollectionHealthPaginator = client.get_paginator("describe_organization_resource_collection_health")
     describe_resource_collection_health_paginator: DescribeResourceCollectionHealthPaginator = client.get_paginator("describe_resource_collection_health")
     get_cost_estimation_paginator: GetCostEstimationPaginator = client.get_paginator("get_cost_estimation")
     get_resource_collection_paginator: GetResourceCollectionPaginator = client.get_paginator("get_resource_collection")
@@ -31,12 +35,15 @@ Usage::
     list_events_paginator: ListEventsPaginator = client.get_paginator("list_events")
     list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
     list_notification_channels_paginator: ListNotificationChannelsPaginator = client.get_paginator("list_notification_channels")
+    list_organization_insights_paginator: ListOrganizationInsightsPaginator = client.get_paginator("list_organization_insights")
     list_recommendations_paginator: ListRecommendationsPaginator = client.get_paginator("list_recommendations")
     search_insights_paginator: SearchInsightsPaginator = client.get_paginator("search_insights")
+    search_organization_insights_paginator: SearchOrganizationInsightsPaginator = client.get_paginator("search_organization_insights")
     ```
 """
 from .client import DevOpsGuruClient
 from .paginator import (
+    DescribeOrganizationResourceCollectionHealthPaginator,
     DescribeResourceCollectionHealthPaginator,
     GetCostEstimationPaginator,
     GetResourceCollectionPaginator,
@@ -44,8 +51,10 @@ from .paginator import (
     ListEventsPaginator,
     ListInsightsPaginator,
     ListNotificationChannelsPaginator,
+    ListOrganizationInsightsPaginator,
     ListRecommendationsPaginator,
     SearchInsightsPaginator,
+    SearchOrganizationInsightsPaginator,
 )
 
 Client = DevOpsGuruClient
@@ -53,6 +62,7 @@ Client = DevOpsGuruClient
 
 __all__ = (
     "Client",
+    "DescribeOrganizationResourceCollectionHealthPaginator",
     "DescribeResourceCollectionHealthPaginator",
     "DevOpsGuruClient",
     "GetCostEstimationPaginator",
@@ -61,6 +71,8 @@ __all__ = (
     "ListEventsPaginator",
     "ListInsightsPaginator",
     "ListNotificationChannelsPaginator",
+    "ListOrganizationInsightsPaginator",
     "ListRecommendationsPaginator",
     "SearchInsightsPaginator",
+    "SearchOrganizationInsightsPaginator",
 )
