@@ -6,9 +6,9 @@ Type annotations for devops-guru service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_devops_guru.type_defs import AddNotificationChannelRequestRequestTypeDef
+    from mypy_boto3_devops_guru.type_defs import AccountHealthTypeDef
 
-    data: AddNotificationChannelRequestRequestTypeDef = {...}
+    data: AccountHealthTypeDef = {...}
     ```
 """
 import sys
@@ -18,6 +18,8 @@ from typing import Dict, List, Sequence, Union
 from .literals import (
     AnomalySeverityType,
     AnomalyStatusType,
+    AnomalyTypeType,
+    CloudWatchMetricDataStatusCodeType,
     CloudWatchMetricsStatType,
     CostEstimationServiceResourceStateType,
     CostEstimationStatusType,
@@ -29,6 +31,7 @@ from .literals import (
     InsightTypeType,
     LocaleType,
     OptInStatusType,
+    OrganizationResourceCollectionTypeType,
     ResourceCollectionTypeType,
     ServiceNameType,
     UpdateResourceCollectionActionType,
@@ -41,15 +44,19 @@ else:
 
 
 __all__ = (
+    "AccountHealthTypeDef",
+    "AccountInsightHealthTypeDef",
     "AddNotificationChannelRequestRequestTypeDef",
     "AddNotificationChannelResponseTypeDef",
     "AnomalyReportedTimeRangeTypeDef",
+    "AnomalyResourceTypeDef",
     "AnomalySourceDetailsTypeDef",
     "AnomalyTimeRangeTypeDef",
     "CloudFormationCollectionFilterTypeDef",
     "CloudFormationCollectionTypeDef",
     "CloudFormationCostEstimationResourceCollectionFilterTypeDef",
     "CloudFormationHealthTypeDef",
+    "CloudWatchMetricsDataSummaryTypeDef",
     "CloudWatchMetricsDetailTypeDef",
     "CloudWatchMetricsDimensionTypeDef",
     "CostEstimationResourceCollectionFilterTypeDef",
@@ -63,6 +70,12 @@ __all__ = (
     "DescribeFeedbackResponseTypeDef",
     "DescribeInsightRequestRequestTypeDef",
     "DescribeInsightResponseTypeDef",
+    "DescribeOrganizationHealthRequestRequestTypeDef",
+    "DescribeOrganizationHealthResponseTypeDef",
+    "DescribeOrganizationOverviewRequestRequestTypeDef",
+    "DescribeOrganizationOverviewResponseTypeDef",
+    "DescribeOrganizationResourceCollectionHealthRequestRequestTypeDef",
+    "DescribeOrganizationResourceCollectionHealthResponseTypeDef",
     "DescribeResourceCollectionHealthRequestRequestTypeDef",
     "DescribeResourceCollectionHealthResponseTypeDef",
     "DescribeServiceIntegrationResponseTypeDef",
@@ -90,6 +103,8 @@ __all__ = (
     "ListInsightsStatusFilterTypeDef",
     "ListNotificationChannelsRequestRequestTypeDef",
     "ListNotificationChannelsResponseTypeDef",
+    "ListOrganizationInsightsRequestRequestTypeDef",
+    "ListOrganizationInsightsResponseTypeDef",
     "ListRecommendationsRequestRequestTypeDef",
     "ListRecommendationsResponseTypeDef",
     "NotificationChannelConfigTypeDef",
@@ -97,16 +112,26 @@ __all__ = (
     "OpsCenterIntegrationConfigTypeDef",
     "OpsCenterIntegrationTypeDef",
     "PaginatorConfigTypeDef",
+    "PerformanceInsightsMetricDimensionGroupTypeDef",
+    "PerformanceInsightsMetricQueryTypeDef",
+    "PerformanceInsightsMetricsDetailTypeDef",
+    "PerformanceInsightsReferenceComparisonValuesTypeDef",
+    "PerformanceInsightsReferenceDataTypeDef",
+    "PerformanceInsightsReferenceMetricTypeDef",
+    "PerformanceInsightsReferenceScalarTypeDef",
+    "PerformanceInsightsStatTypeDef",
     "PredictionTimeRangeTypeDef",
     "ProactiveAnomalySummaryTypeDef",
     "ProactiveAnomalyTypeDef",
     "ProactiveInsightSummaryTypeDef",
     "ProactiveInsightTypeDef",
+    "ProactiveOrganizationInsightSummaryTypeDef",
     "PutFeedbackRequestRequestTypeDef",
     "ReactiveAnomalySummaryTypeDef",
     "ReactiveAnomalyTypeDef",
     "ReactiveInsightSummaryTypeDef",
     "ReactiveInsightTypeDef",
+    "ReactiveOrganizationInsightSummaryTypeDef",
     "RecommendationRelatedAnomalyResourceTypeDef",
     "RecommendationRelatedAnomalySourceDetailTypeDef",
     "RecommendationRelatedAnomalyTypeDef",
@@ -121,6 +146,9 @@ __all__ = (
     "SearchInsightsFiltersTypeDef",
     "SearchInsightsRequestRequestTypeDef",
     "SearchInsightsResponseTypeDef",
+    "SearchOrganizationInsightsFiltersTypeDef",
+    "SearchOrganizationInsightsRequestRequestTypeDef",
+    "SearchOrganizationInsightsResponseTypeDef",
     "ServiceCollectionTypeDef",
     "ServiceHealthTypeDef",
     "ServiceInsightHealthTypeDef",
@@ -129,11 +157,35 @@ __all__ = (
     "SnsChannelConfigTypeDef",
     "StartCostEstimationRequestRequestTypeDef",
     "StartTimeRangeTypeDef",
+    "TagCollectionFilterTypeDef",
+    "TagCollectionTypeDef",
+    "TagCostEstimationResourceCollectionFilterTypeDef",
+    "TagHealthTypeDef",
+    "TimestampMetricValuePairTypeDef",
     "UpdateCloudFormationCollectionFilterTypeDef",
     "UpdateResourceCollectionFilterTypeDef",
     "UpdateResourceCollectionRequestRequestTypeDef",
     "UpdateServiceIntegrationConfigTypeDef",
     "UpdateServiceIntegrationRequestRequestTypeDef",
+    "UpdateTagCollectionFilterTypeDef",
+)
+
+AccountHealthTypeDef = TypedDict(
+    "AccountHealthTypeDef",
+    {
+        "AccountId": str,
+        "Insight": "AccountInsightHealthTypeDef",
+    },
+    total=False,
+)
+
+AccountInsightHealthTypeDef = TypedDict(
+    "AccountInsightHealthTypeDef",
+    {
+        "OpenProactiveInsights": int,
+        "OpenReactiveInsights": int,
+    },
+    total=False,
 )
 
 AddNotificationChannelRequestRequestTypeDef = TypedDict(
@@ -172,10 +224,20 @@ class AnomalyReportedTimeRangeTypeDef(
     pass
 
 
+AnomalyResourceTypeDef = TypedDict(
+    "AnomalyResourceTypeDef",
+    {
+        "Name": str,
+        "Type": str,
+    },
+    total=False,
+)
+
 AnomalySourceDetailsTypeDef = TypedDict(
     "AnomalySourceDetailsTypeDef",
     {
         "CloudWatchMetrics": List["CloudWatchMetricsDetailTypeDef"],
+        "PerformanceInsightsMetrics": List["PerformanceInsightsMetricsDetailTypeDef"],
     },
     total=False,
 )
@@ -232,6 +294,15 @@ CloudFormationHealthTypeDef = TypedDict(
     total=False,
 )
 
+CloudWatchMetricsDataSummaryTypeDef = TypedDict(
+    "CloudWatchMetricsDataSummaryTypeDef",
+    {
+        "TimestampMetricValuePairList": List["TimestampMetricValuePairTypeDef"],
+        "StatusCode": CloudWatchMetricDataStatusCodeType,
+    },
+    total=False,
+)
+
 CloudWatchMetricsDetailTypeDef = TypedDict(
     "CloudWatchMetricsDetailTypeDef",
     {
@@ -241,6 +312,7 @@ CloudWatchMetricsDetailTypeDef = TypedDict(
         "Stat": CloudWatchMetricsStatType,
         "Unit": str,
         "Period": int,
+        "MetricDataSummary": "CloudWatchMetricsDataSummaryTypeDef",
     },
     total=False,
 )
@@ -258,6 +330,7 @@ CostEstimationResourceCollectionFilterTypeDef = TypedDict(
     "CostEstimationResourceCollectionFilterTypeDef",
     {
         "CloudFormation": "CloudFormationCostEstimationResourceCollectionFilterTypeDef",
+        "Tags": List["TagCostEstimationResourceCollectionFilterTypeDef"],
     },
     total=False,
 )
@@ -314,12 +387,26 @@ DescribeAccountOverviewResponseTypeDef = TypedDict(
     },
 )
 
-DescribeAnomalyRequestRequestTypeDef = TypedDict(
-    "DescribeAnomalyRequestRequestTypeDef",
+_RequiredDescribeAnomalyRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeAnomalyRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
+_OptionalDescribeAnomalyRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeAnomalyRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class DescribeAnomalyRequestRequestTypeDef(
+    _RequiredDescribeAnomalyRequestRequestTypeDef, _OptionalDescribeAnomalyRequestRequestTypeDef
+):
+    pass
+
 
 DescribeAnomalyResponseTypeDef = TypedDict(
     "DescribeAnomalyResponseTypeDef",
@@ -346,12 +433,26 @@ DescribeFeedbackResponseTypeDef = TypedDict(
     },
 )
 
-DescribeInsightRequestRequestTypeDef = TypedDict(
-    "DescribeInsightRequestRequestTypeDef",
+_RequiredDescribeInsightRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeInsightRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
+_OptionalDescribeInsightRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeInsightRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class DescribeInsightRequestRequestTypeDef(
+    _RequiredDescribeInsightRequestRequestTypeDef, _OptionalDescribeInsightRequestRequestTypeDef
+):
+    pass
+
 
 DescribeInsightResponseTypeDef = TypedDict(
     "DescribeInsightResponseTypeDef",
@@ -362,6 +463,96 @@ DescribeInsightResponseTypeDef = TypedDict(
     },
 )
 
+DescribeOrganizationHealthRequestRequestTypeDef = TypedDict(
+    "DescribeOrganizationHealthRequestRequestTypeDef",
+    {
+        "AccountIds": Sequence[str],
+        "OrganizationalUnitIds": Sequence[str],
+    },
+    total=False,
+)
+
+DescribeOrganizationHealthResponseTypeDef = TypedDict(
+    "DescribeOrganizationHealthResponseTypeDef",
+    {
+        "OpenReactiveInsights": int,
+        "OpenProactiveInsights": int,
+        "MetricsAnalyzed": int,
+        "ResourceHours": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeOrganizationOverviewRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeOrganizationOverviewRequestRequestTypeDef",
+    {
+        "FromTime": Union[datetime, str],
+    },
+)
+_OptionalDescribeOrganizationOverviewRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeOrganizationOverviewRequestRequestTypeDef",
+    {
+        "ToTime": Union[datetime, str],
+        "AccountIds": Sequence[str],
+        "OrganizationalUnitIds": Sequence[str],
+    },
+    total=False,
+)
+
+
+class DescribeOrganizationOverviewRequestRequestTypeDef(
+    _RequiredDescribeOrganizationOverviewRequestRequestTypeDef,
+    _OptionalDescribeOrganizationOverviewRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeOrganizationOverviewResponseTypeDef = TypedDict(
+    "DescribeOrganizationOverviewResponseTypeDef",
+    {
+        "ReactiveInsights": int,
+        "ProactiveInsights": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef",
+    {
+        "OrganizationResourceCollectionType": OrganizationResourceCollectionTypeType,
+    },
+)
+_OptionalDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef",
+    {
+        "AccountIds": Sequence[str],
+        "OrganizationalUnitIds": Sequence[str],
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class DescribeOrganizationResourceCollectionHealthRequestRequestTypeDef(
+    _RequiredDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef,
+    _OptionalDescribeOrganizationResourceCollectionHealthRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeOrganizationResourceCollectionHealthResponseTypeDef = TypedDict(
+    "DescribeOrganizationResourceCollectionHealthResponseTypeDef",
+    {
+        "CloudFormation": List["CloudFormationHealthTypeDef"],
+        "Service": List["ServiceHealthTypeDef"],
+        "Account": List["AccountHealthTypeDef"],
+        "NextToken": str,
+        "Tags": List["TagHealthTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredDescribeResourceCollectionHealthRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeResourceCollectionHealthRequestRequestTypeDef",
     {
@@ -390,6 +581,7 @@ DescribeResourceCollectionHealthResponseTypeDef = TypedDict(
         "CloudFormation": List["CloudFormationHealthTypeDef"],
         "Service": List["ServiceHealthTypeDef"],
         "NextToken": str,
+        "Tags": List["TagHealthTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -546,6 +738,7 @@ _OptionalListAnomaliesForInsightRequestRequestTypeDef = TypedDict(
         "StartTimeRange": "StartTimeRangeTypeDef",
         "MaxResults": int,
         "NextToken": str,
+        "AccountId": str,
     },
     total=False,
 )
@@ -592,6 +785,7 @@ _OptionalListEventsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
+        "AccountId": str,
     },
     total=False,
 )
@@ -694,6 +888,41 @@ ListNotificationChannelsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListOrganizationInsightsRequestRequestTypeDef = TypedDict(
+    "_RequiredListOrganizationInsightsRequestRequestTypeDef",
+    {
+        "StatusFilter": "ListInsightsStatusFilterTypeDef",
+    },
+)
+_OptionalListOrganizationInsightsRequestRequestTypeDef = TypedDict(
+    "_OptionalListOrganizationInsightsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "AccountIds": Sequence[str],
+        "OrganizationalUnitIds": Sequence[str],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListOrganizationInsightsRequestRequestTypeDef(
+    _RequiredListOrganizationInsightsRequestRequestTypeDef,
+    _OptionalListOrganizationInsightsRequestRequestTypeDef,
+):
+    pass
+
+
+ListOrganizationInsightsResponseTypeDef = TypedDict(
+    "ListOrganizationInsightsResponseTypeDef",
+    {
+        "ProactiveInsights": List["ProactiveOrganizationInsightSummaryTypeDef"],
+        "ReactiveInsights": List["ReactiveOrganizationInsightSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
     "_RequiredListRecommendationsRequestRequestTypeDef",
     {
@@ -705,6 +934,7 @@ _OptionalListRecommendationsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "Locale": LocaleType,
+        "AccountId": str,
     },
     total=False,
 )
@@ -768,6 +998,82 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+PerformanceInsightsMetricDimensionGroupTypeDef = TypedDict(
+    "PerformanceInsightsMetricDimensionGroupTypeDef",
+    {
+        "Group": str,
+        "Dimensions": List[str],
+        "Limit": int,
+    },
+    total=False,
+)
+
+PerformanceInsightsMetricQueryTypeDef = TypedDict(
+    "PerformanceInsightsMetricQueryTypeDef",
+    {
+        "Metric": str,
+        "GroupBy": "PerformanceInsightsMetricDimensionGroupTypeDef",
+        "Filter": Dict[str, str],
+    },
+    total=False,
+)
+
+PerformanceInsightsMetricsDetailTypeDef = TypedDict(
+    "PerformanceInsightsMetricsDetailTypeDef",
+    {
+        "MetricDisplayName": str,
+        "Unit": str,
+        "MetricQuery": "PerformanceInsightsMetricQueryTypeDef",
+        "ReferenceData": List["PerformanceInsightsReferenceDataTypeDef"],
+        "StatsAtAnomaly": List["PerformanceInsightsStatTypeDef"],
+        "StatsAtBaseline": List["PerformanceInsightsStatTypeDef"],
+    },
+    total=False,
+)
+
+PerformanceInsightsReferenceComparisonValuesTypeDef = TypedDict(
+    "PerformanceInsightsReferenceComparisonValuesTypeDef",
+    {
+        "ReferenceScalar": "PerformanceInsightsReferenceScalarTypeDef",
+        "ReferenceMetric": "PerformanceInsightsReferenceMetricTypeDef",
+    },
+    total=False,
+)
+
+PerformanceInsightsReferenceDataTypeDef = TypedDict(
+    "PerformanceInsightsReferenceDataTypeDef",
+    {
+        "Name": str,
+        "ComparisonValues": "PerformanceInsightsReferenceComparisonValuesTypeDef",
+    },
+    total=False,
+)
+
+PerformanceInsightsReferenceMetricTypeDef = TypedDict(
+    "PerformanceInsightsReferenceMetricTypeDef",
+    {
+        "MetricQuery": "PerformanceInsightsMetricQueryTypeDef",
+    },
+    total=False,
+)
+
+PerformanceInsightsReferenceScalarTypeDef = TypedDict(
+    "PerformanceInsightsReferenceScalarTypeDef",
+    {
+        "Value": float,
+    },
+    total=False,
+)
+
+PerformanceInsightsStatTypeDef = TypedDict(
+    "PerformanceInsightsStatTypeDef",
+    {
+        "Type": str,
+        "Value": float,
+    },
+    total=False,
+)
+
 _RequiredPredictionTimeRangeTypeDef = TypedDict(
     "_RequiredPredictionTimeRangeTypeDef",
     {
@@ -836,6 +1142,7 @@ ProactiveInsightSummaryTypeDef = TypedDict(
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
         "ServiceCollection": "ServiceCollectionTypeDef",
+        "AssociatedResourceArns": List[str],
     },
     total=False,
 )
@@ -855,6 +1162,23 @@ ProactiveInsightTypeDef = TypedDict(
     total=False,
 )
 
+ProactiveOrganizationInsightSummaryTypeDef = TypedDict(
+    "ProactiveOrganizationInsightSummaryTypeDef",
+    {
+        "Id": str,
+        "AccountId": str,
+        "OrganizationalUnitId": str,
+        "Name": str,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
+        "InsightTimeRange": "InsightTimeRangeTypeDef",
+        "PredictionTimeRange": "PredictionTimeRangeTypeDef",
+        "ResourceCollection": "ResourceCollectionTypeDef",
+        "ServiceCollection": "ServiceCollectionTypeDef",
+    },
+    total=False,
+)
+
 PutFeedbackRequestRequestTypeDef = TypedDict(
     "PutFeedbackRequestRequestTypeDef",
     {
@@ -874,6 +1198,11 @@ ReactiveAnomalySummaryTypeDef = TypedDict(
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
         "ResourceCollection": "ResourceCollectionTypeDef",
+        "Type": AnomalyTypeType,
+        "Name": str,
+        "Description": str,
+        "CausalAnomalyId": str,
+        "AnomalyResources": List["AnomalyResourceTypeDef"],
     },
     total=False,
 )
@@ -889,6 +1218,11 @@ ReactiveAnomalyTypeDef = TypedDict(
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
         "ResourceCollection": "ResourceCollectionTypeDef",
+        "Type": AnomalyTypeType,
+        "Name": str,
+        "Description": str,
+        "CausalAnomalyId": str,
+        "AnomalyResources": List["AnomalyResourceTypeDef"],
     },
     total=False,
 )
@@ -903,6 +1237,7 @@ ReactiveInsightSummaryTypeDef = TypedDict(
         "InsightTimeRange": "InsightTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
         "ServiceCollection": "ServiceCollectionTypeDef",
+        "AssociatedResourceArns": List[str],
     },
     total=False,
 )
@@ -921,6 +1256,22 @@ ReactiveInsightTypeDef = TypedDict(
     total=False,
 )
 
+ReactiveOrganizationInsightSummaryTypeDef = TypedDict(
+    "ReactiveOrganizationInsightSummaryTypeDef",
+    {
+        "Id": str,
+        "AccountId": str,
+        "OrganizationalUnitId": str,
+        "Name": str,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
+        "InsightTimeRange": "InsightTimeRangeTypeDef",
+        "ResourceCollection": "ResourceCollectionTypeDef",
+        "ServiceCollection": "ServiceCollectionTypeDef",
+    },
+    total=False,
+)
+
 RecommendationRelatedAnomalyResourceTypeDef = TypedDict(
     "RecommendationRelatedAnomalyResourceTypeDef",
     {
@@ -943,6 +1294,7 @@ RecommendationRelatedAnomalyTypeDef = TypedDict(
     {
         "Resources": List["RecommendationRelatedAnomalyResourceTypeDef"],
         "SourceDetails": List["RecommendationRelatedAnomalySourceDetailTypeDef"],
+        "AnomalyId": str,
     },
     total=False,
 )
@@ -998,6 +1350,7 @@ ResourceCollectionFilterTypeDef = TypedDict(
     "ResourceCollectionFilterTypeDef",
     {
         "CloudFormation": "CloudFormationCollectionFilterTypeDef",
+        "Tags": List["TagCollectionFilterTypeDef"],
     },
     total=False,
 )
@@ -1006,6 +1359,7 @@ ResourceCollectionTypeDef = TypedDict(
     "ResourceCollectionTypeDef",
     {
         "CloudFormation": "CloudFormationCollectionTypeDef",
+        "Tags": List["TagCollectionTypeDef"],
     },
     total=False,
 )
@@ -1066,6 +1420,53 @@ SearchInsightsResponseTypeDef = TypedDict(
     },
 )
 
+SearchOrganizationInsightsFiltersTypeDef = TypedDict(
+    "SearchOrganizationInsightsFiltersTypeDef",
+    {
+        "Severities": Sequence[InsightSeverityType],
+        "Statuses": Sequence[InsightStatusType],
+        "ResourceCollection": "ResourceCollectionTypeDef",
+        "ServiceCollection": "ServiceCollectionTypeDef",
+    },
+    total=False,
+)
+
+_RequiredSearchOrganizationInsightsRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchOrganizationInsightsRequestRequestTypeDef",
+    {
+        "AccountIds": Sequence[str],
+        "StartTimeRange": "StartTimeRangeTypeDef",
+        "Type": InsightTypeType,
+    },
+)
+_OptionalSearchOrganizationInsightsRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchOrganizationInsightsRequestRequestTypeDef",
+    {
+        "Filters": "SearchOrganizationInsightsFiltersTypeDef",
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class SearchOrganizationInsightsRequestRequestTypeDef(
+    _RequiredSearchOrganizationInsightsRequestRequestTypeDef,
+    _OptionalSearchOrganizationInsightsRequestRequestTypeDef,
+):
+    pass
+
+
+SearchOrganizationInsightsResponseTypeDef = TypedDict(
+    "SearchOrganizationInsightsResponseTypeDef",
+    {
+        "ProactiveInsights": List["ProactiveInsightSummaryTypeDef"],
+        "ReactiveInsights": List["ReactiveInsightSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ServiceCollectionTypeDef = TypedDict(
     "ServiceCollectionTypeDef",
     {
@@ -1151,6 +1552,49 @@ StartTimeRangeTypeDef = TypedDict(
     total=False,
 )
 
+TagCollectionFilterTypeDef = TypedDict(
+    "TagCollectionFilterTypeDef",
+    {
+        "AppBoundaryKey": str,
+        "TagValues": List[str],
+    },
+)
+
+TagCollectionTypeDef = TypedDict(
+    "TagCollectionTypeDef",
+    {
+        "AppBoundaryKey": str,
+        "TagValues": List[str],
+    },
+)
+
+TagCostEstimationResourceCollectionFilterTypeDef = TypedDict(
+    "TagCostEstimationResourceCollectionFilterTypeDef",
+    {
+        "AppBoundaryKey": str,
+        "TagValues": List[str],
+    },
+)
+
+TagHealthTypeDef = TypedDict(
+    "TagHealthTypeDef",
+    {
+        "AppBoundaryKey": str,
+        "TagValue": str,
+        "Insight": "InsightHealthTypeDef",
+    },
+    total=False,
+)
+
+TimestampMetricValuePairTypeDef = TypedDict(
+    "TimestampMetricValuePairTypeDef",
+    {
+        "Timestamp": datetime,
+        "MetricValue": float,
+    },
+    total=False,
+)
+
 UpdateCloudFormationCollectionFilterTypeDef = TypedDict(
     "UpdateCloudFormationCollectionFilterTypeDef",
     {
@@ -1163,6 +1607,7 @@ UpdateResourceCollectionFilterTypeDef = TypedDict(
     "UpdateResourceCollectionFilterTypeDef",
     {
         "CloudFormation": "UpdateCloudFormationCollectionFilterTypeDef",
+        "Tags": Sequence["UpdateTagCollectionFilterTypeDef"],
     },
     total=False,
 )
@@ -1189,3 +1634,11 @@ UpdateServiceIntegrationRequestRequestTypeDef = TypedDict(
         "ServiceIntegration": "UpdateServiceIntegrationConfigTypeDef",
     },
 )
+
+UpdateTagCollectionFilterTypeDef = TypedDict(
+    "UpdateTagCollectionFilterTypeDef",
+    {
+        "AppBoundaryKey": str,
+        "TagValues": Sequence[str],
+    },
+)
